The router used by the current request. This is the same as (:reitit.core/router *request*)
The router used by the current request. This is the same as `(:reitit.core/router *request*)`
The session in the current request. This is the same as (:session *request*)
The session in the current request. This is the same as `(:session *request*)`
(html-response doc)(html-response status doc)Return an HTML ring response. Attempt to render the body as HTML unless its already a string.
Return an HTML ring response. Attempt to render the body as HTML unless its already a string.
(json-response data)(json-response status data)Return a JSON ring response. Attempt to render the body as JSON unless its already a string.
Return a JSON ring response. Attempt to render the body as JSON unless its already a string.
(start)(start options)Start the zodiac server. Returns an integrant system map.
Start the zodiac server. Returns an integrant system map.
(stop system)Stop the zodiac server. Accepts the system map returned from z/start.
Stop the zodiac server. Accepts the system map returned from z/start.
(url-for name-or-path)(url-for name-or-path args)(url-for name-or-path args query-params)Return a url string given a route name and optional arg and query params. This functions uses the router for the current request bound to request.
If you need to use a different router then temporary bind router before calling this function.
Return a url string given a route name and optional arg and query params. This functions uses the router for the current request bound to *request*. If you need to use a different router then temporary bind *router* before calling this function.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |